@@ -76,7 +76,7 @@
 #undef GetObject
 #endif
 
-static Lum::AppInfo info;
+static Lum::Def::AppInfo info;
 
 struct DiskInfo
 {
